pyxmpp2.mainloop.interfaces.TimeoutHandler

Package pyxmpp2 :: Package mainloop :: Module interfaces :: Class TimeoutHandler |
[hide private]

# Class TimeoutHandler

Base class for PyXMPP timeout handlers.

Nested Classes | [hide private]
| __metaclass__ Metaclass for defining Abstract Base Classes (ABCs).

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| __abstractmethods__ = ``frozenset([``])``
| _abc_cache = `<_weakrefset.WeakSet object at 0x871986c>`
| _abc_negative_cache = `<_weakrefset.WeakSet object at 0x87198ac>`
| _abc_negative_cache_version = `10`
| _abc_registry = `<_weakrefset.WeakSet object at 0x871980c>`

Properties | [hide private]
Inherited from `object`: `__class__`